@@ -24,7 +24,9 @@ async def talk(command, fps, command_id, positioner_id, params):
     """Send a direct command to the CAN network and show the replies."""
 
     CommandClass = CommandID(command_id).get_command_class()
-    can_command = CommandClass(*params, positioner_id=positioner_id)
+    assert CommandClass
+
+    can_command = CommandClass(positioner_id, *params)
 
     command.info(f"Running command {can_command.command_id.name}.")
 
