@@ -43,7 +43,11 @@ class CommandID(enum.IntEnum, metaclass=TypesEnumMeta):
     GO_TO_DATUM_ALPHA = 21
     GO_TO_DATUM_BETA = 22
     START_DATUM_CALIBRATION = 23
+    START_DATUM_CALIBRATION_ALPHA = 24
+    START_DATUM_CALIBRATION_BETA = 25
     START_MOTOR_CALIBRATION = 26
+    START_MOTOR_CALIBRATION_ALPHA = 26
+    START_MOTOR_CALIBRATION_BETA = 27
     GO_TO_ABSOLUTE_POSITION = 30
     GO_TO_RELATIVE_POSITION = 31
     GET_ACTUAL_POSITION = 32
@@ -54,6 +58,8 @@ class CommandID(enum.IntEnum, metaclass=TypesEnumMeta):
     SET_CURRENT = 41
     GET_HALL_CALIB_ERROR = 45
     START_COGGING_CALIBRATION = 47
+    START_COGGING_CALIBRATION_ALPHA = 48
+    START_COGGING_CALIBRATION_BETA = 49
     SAVE_INTERNAL_CALIBRATION = 53
     GET_CURRENT = 56
     GET_ALPHA_HALL_CALIB = 104
